/// @brief Clase Aranya.
///
/// Esta clase servirá para representar a la araña con la que se juega.

#ifndef ARANYA_H
#define ARANYA_H

#include <Gosu/Gosu.hpp>
#include "Constantes.h"
using namespace std;
class Ventana;
class Aranya{
   public:
      /// @brief Crea una araña.
      /// @return Objeto inicializado de la clase Aranya.
      //Aranya(float x, float y, float w, float h, int arma);
      Aranya(Gosu::Graphics& graphics);
		/// @brief Elimina un objeto Aranya y libera su espacio en memoria.
      ~Aranya();
		/// @brief Incrementa o decrementa la posición horizontal de la araña en el nivel en posx.
      void movX(int posx);
		/// @brief Incrementa o decrementa la posición vertical de la araña en el nivel en posy.
      void movY(int posy);
		/// @brief Devuelve la posición en el eje x de la araña en el nivel.
		/// @return Atributo movX_ que contiene la posición en el eje x de la araña en el nivel.
      int movX() const;

		/// @brief Devuelve la posición en el eje x de la araña en la ventana.
		/// @return Atributo posX_ que contiene la posición en el eje x de la araña en la ventana.
      int posX() const;
		/// @brief Devuelve la posición en el eje y de la araña en la ventana.
		/// @return Atributo posY_ que contiene la posición en el eje y de la araña en la ventana.
      int posY() const;
		/// @brief Devuelve el ancho de la araña.
		/// @return Atributo w_ que contiene el ancho de la araña.
      int width() const;
		/// @brief Devuelve la altura de la araña.
		/// @return Atributo h_ que contiene la altura de la araña.
      int height() const;
		
		void sonidoSalto();
		void sonidoComida();
		
		bool muerta();
		void muerta(bool valor);
		
		vector<Gosu::Image*>& movder();
		vector<Gosu::Image*>& movizq();
		vector<Gosu::Image*>& mova();
		
		pair<int,int>& md();
		pair<int,int>& mi();
		pair<int,int>& ma();

		int& direccion();
		int direccion() const;
		
		bool& saltando();
		bool saltando() const;
		
		void reiniciarValores();
		void come();
		int puntos() const;
		
   private:
   	void inicializarImagenes(Gosu::Graphics& graphics);
      //Posición horizontal y vertical
      /// @ {
      /// @name CoordenadasAranya
      int posX_,posY_;
      /// @ }
      //Alto y ancho
      /// @ {
      /// @name ProporcionesAranya
      int w_,h_;
      /// @ }
      int arma_; //Indicará el arma que lleve la araña
      /// Gosu::Image *aranya_;
      /// @name VelocidadesAranya
      int velX_,velY_;
      /// @ }
      int movX_;
      
      Gosu::Sample *sonidoSalto_,*sonidoComida_;
      bool muerta_;
      vector<Gosu::Image*> movder_,movizq_,mova_;
      pair <int,int> md_,mi_,ma_;

		int direccion_;
      bool saltando_;
      int puntos_;
};

#endif

