#ifndef OBSTACULO_H
#define OBSTACULO_H

#include <Gosu/Gosu.hpp>

/// @brief Clase Obstaculo.
///
/// Esta clase servirá para representar los obstáculos.
/// @author Rodríguez Quirós, Estefanía
/// @version 0.1

using namespace std;

class Obstaculo
{
   public:
	   /// @brief Crea un objeto de la clase Obstaculo
	   /// @return Objeto inicializado de la clase Obstaculo
      Obstaculo(Gosu::Graphics& graphics, int posX, int posY, int width, int height);
      /// @brief Elimina un objeto Obstaculo y libera su espacio en memoria.
		virtual ~Obstaculo();
		/// @brief Devuelve la posición en el eje x del obstáculo en el nivel.
	   /// @return Atributo posX_ que contiene la posición en el eje x del obstáculo en el nivel.
      int posX();
		/// @brief Devuelve la posición en el eje y del obstáculo en el nivel.
	   /// @return Atributo posX_ que contiene la posición en el eje y del obstáculo en el nivel.
      int posY();
		/// @brief Devuelve el ancho del obstáculo.
	   /// @return Atributo width_ que contiene los píxeles de ancho del obstáculo.
      int width();
		/// @brief Devuelve el alto del obstáculo.
	   /// @return Atributo height_ que contiene los píxeles de alto del obstáculo.
      int height();
      void draw(int x, int y, int z = 1);
   private:
      int posX_,posY_,width_,height_;
   protected:
      Gosu::Image *img_;
};

/// @brief Clase Basura.
///
/// Esta clase servirá para representar un cubo de basura, un tipo de Obstáculo.
/// @author Ruso Amieva, Antonio
/// @version 0.1
class Basura : virtual public Obstaculo
{
   public:
	   /// @brief Crea un objeto de la clase Basura
	   /// @return Objeto inicializado de la clase Basura
      Basura(Gosu::Graphics& graphics, int posX, int posY);
};

/// @brief Clase Caja.
///
/// Esta clase servirá para representar una caja de cartón, un tipo de Obstáculo.
/// @author Ruso Amieva, Antonio
/// @version 0.1
class Caja : virtual public Obstaculo
{
   public:
	   /// @brief Crea un objeto de la clase Caja
	   /// @return Objeto inicializado de la clase Caja
	   Caja(Gosu::Graphics& graphics, int posX, int posY);
};

class Arbol : virtual public Obstaculo
{
   public:
	   /// @brief Crea un objeto de la clase Arbol
	   /// @return Objeto inicializado de la clase Arbol
	   Arbol(Gosu::Graphics& graphics, int posX, int posY);
};

class Banco : virtual public Obstaculo
{
   public:
	   /// @brief Crea un objeto de la clase Banco
	   /// @return Objeto inicializado de la clase Banco
	   Banco(Gosu::Graphics& graphics, int posX, int posY);
};

class Farola : virtual public Obstaculo
{
   public:
	   /// @brief Crea un objeto de la clase Farola
	   /// @return Objeto inicializado de la clase Farola
	   Farola(Gosu::Graphics& graphics, int posX, int posY);
};

/// @brief Clase Encimera
class Encimera : virtual public Obstaculo
{
   public:
	   /// @brief Crea un objeto de la clase Encimera
	   /// @return Objeto inicializado de la clase Encimera
	   Encimera(Gosu::Graphics& graphics, int posX, int posY);
};

/// @brief Clase Taburete
class Taburete : virtual public Obstaculo
{
   public:
	   /// @brief Crea un objeto de la clase Taburete
	   /// @return Objeto inicializado de la clase Taburete
	   Taburete(Gosu::Graphics& graphics, int posX, int posY);
};

/// @brief Clase Mesa
class Mesa : virtual public Obstaculo
{
   public:
	   /// @brief Crea un objeto de la clase Mesa
	   /// @return Objeto inicializado de la clase Mesa
	   Mesa(Gosu::Graphics& graphics, int posX, int posY);
};

/// @brief Clase Estanteria
class Estanteria : virtual public Obstaculo
{
   public:
	   /// @brief Crea un objeto de la clase Estanteria
	   /// @return Objeto inicializado de la clase Estanteria
	   Estanteria(Gosu::Graphics& graphics, int posX, int posY);
};

/// @brief Clase Sofa
class Sofa : virtual public Obstaculo
{
   public:
	   /// @brief Crea un objeto de la clase Sofa
	   /// @return Objeto inicializado de la clase Sofa
	   Sofa(Gosu::Graphics& graphics, int posX, int posY);
};

/// @brief Clase Sofa
class Lampara : virtual public Obstaculo
{
   public:
	   /// @brief Crea un objeto de la clase Lampara
	   /// @return Objeto inicializado de la clase Lampara
	   Lampara(Gosu::Graphics& graphics, int posX, int posY);
};

#endif

